@@ -180,14 +180,10 @@ def imagine(
                     half_mode=half_mode,
                     for_inpainting=prompt.mask_image or prompt.mask_prompt or prompt.outpaint,
                 )
-                midas_model = None
                 safety_feature_extractor = None
                 safety_checker = None
                 codeformer_net_model = None
 
-                if prompt.init_image:
-                    from modules.midas.utils import AddMiDaS
-                    midas_model = AddMiDaS()
 
                 if nsfw_filter:
                     from transformers import AutoFeatureExtractor
@@ -205,7 +201,6 @@ def imagine(
                 result = _generate_single_image(
                     prompt,
                     model,
-                    midas_model=midas_model,
                     nsfw_filter=nsfw_filter,
                     safety_feature_extractor=safety_feature_extractor,
                     safety_checker=safety_checker,
@@ -214,7 +209,6 @@ def imagine(
                     progress_img_callback=progress_img_callback,
                     progress_img_interval_steps=progress_img_interval_steps,
                     progress_img_interval_min_s=progress_img_interval_min_s,
-                    half_mode=half_mode,
                     add_caption=add_caption,
                 )
                 if not result.safety_score.is_filtered:
@@ -237,7 +231,6 @@ def _generate_single_image(
         progress_img_interval_steps=3,
         progress_img_interval_min_s=0.1,
         add_caption=False,
-        suppress_inpaint=False,
         return_latent=False,
 ):
     import torch.nn
@@ -576,56 +569,56 @@ def _generate_single_image(
             caption = generate_caption(gen_img)
             logger.info(f"Generated caption: {caption}")
 
-            if nsfw_filter:
-                with lc.timing("safety-filter"):
-                    safety_score = create_safety_score(
-                        safety_checker,
-                        safety_feature_extractor,
-                        gen_img,
-                        safety_mode=IMAGINAIRY_SAFETY_MODE,
-                    )
-            if nsfw_filter and safety_score.is_filtered:
-                progress_latents.clear()
-            if not nsfw_filter or not safety_score.is_filtered:
-                if prompt.fix_faces and codformer_model:
-                    logger.info("Fixing 😊 's in 🖼  using CodeFormer...")
-                    with lc.timing("face enhancement"):
-                        gen_img = enhance_faces(gen_img,
-                                            net=codformer_model,
-                                            fidelity=prompt.fix_faces_fidelity)
-                if prompt.upscale:
-                    logger.info("Upscaling 🖼  using real-ESRGAN...")
-                    with lc.timing("upscaling"):
-                        upscaled_img = upscale_image(gen_img)
-
-            # put the newly generated patch back into the original, full-size image
-            if prompt.mask_modify_original and mask_image_orig and starting_image:
-                img_to_add_back_to_original = upscaled_img if upscaled_img else gen_img
-                rebuilt_orig_img = combine_image(
-                    original_img=starting_image,
-                    generated_img=img_to_add_back_to_original,
-                    mask_img=mask_image_orig,
+        if nsfw_filter:
+            with lc.timing("safety-filter"):
+                safety_score = create_safety_score(
+                    safety_checker,
+                    safety_feature_extractor,
+                    gen_img,
+                    safety_mode=IMAGINAIRY_SAFETY_MODE,
                 )
+        if nsfw_filter and safety_score.is_filtered:
+            progress_latents.clear()
+        if not nsfw_filter or not safety_score.is_filtered:
+            if prompt.fix_faces and codformer_model:
+                logger.info("Fixing 😊 's in 🖼  using CodeFormer...")
+                with lc.timing("face enhancement"):
+                    gen_img = enhance_faces(gen_img,
+                                        net=codformer_model,
+                                        fidelity=prompt.fix_faces_fidelity)
+            if prompt.upscale:
+                logger.info("Upscaling 🖼  using real-ESRGAN...")
+                with lc.timing("upscaling"):
+                    upscaled_img = upscale_image(gen_img)
 
-            if prompt.caption_text:
-                add_caption_to_image(gen_img, prompt.caption_text)
-
-            result = ImagineResult(
-                img=gen_img,
-                prompt=prompt,
-                upscaled_img=upscaled_img,
-                is_nsfw=False if nsfw_filter is False else safety_score.is_nsfw,
-                safety_score=None if nsfw_filter is False else safety_score,
-                modified_original=rebuilt_orig_img,
-                mask_binary=mask_image_orig,
-                mask_grayscale=mask_grayscale,
-                result_images=result_images,
-                timings=lc.get_timings(),
-                progress_latents=progress_latents.copy(),
+        # put the newly generated patch back into the original, full-size image
+        if prompt.mask_modify_original and mask_image_orig and starting_image:
+            img_to_add_back_to_original = upscaled_img if upscaled_img else gen_img
+            rebuilt_orig_img = combine_image(
+                original_img=starting_image,
+                generated_img=img_to_add_back_to_original,
+                mask_img=mask_image_orig,
             )
-            _most_recent_result = result
-            logger.info(f"Image Generated. Timings: {result.timings_str()}")
-            return result
+
+        if prompt.caption_text:
+            add_caption_to_image(gen_img, prompt.caption_text)
+
+        result = ImagineResult(
+            img=gen_img,
+            prompt=prompt,
+            upscaled_img=upscaled_img,
+            is_nsfw=False if nsfw_filter is False else safety_score.is_nsfw,
+            safety_score=None if nsfw_filter is False else safety_score,
+            modified_original=rebuilt_orig_img,
+            mask_binary=mask_image_orig,
+            mask_grayscale=mask_grayscale,
+            result_images=result_images,
+            timings=lc.get_timings(),
+            progress_latents=progress_latents.copy(),
+        )
+        _most_recent_result = result
+        logger.info(f"Image Generated. Timings: {result.timings_str()}")
+        return result
 
 
 def _prompts_to_embeddings(prompts, model):
