@@ -678,7 +678,7 @@ def _imagine_cmd(
         return
 
     if version:
-        from imaginairy.version import get_version
+        from classy_imaginary.version import get_version
 
         print(get_version())
         return
@@ -695,7 +695,7 @@ def _imagine_cmd(
         )
         print(msg)
 
-    from imaginairy.log_utils import configure_logging
+    from classy_imaginary.log_utils import configure_logging
 
     configure_logging(log_level)
 
