@@ -414,7 +414,7 @@ def train_diffusion_model(
     # add callback which sets up log directory
     default_callbacks_cfg = {
         "setup_callback": {
-            "target": "imaginairy.train.SetupCallback",
+            "target": "classy_imaginary.train.SetupCallback",
             "params": {
                 "resume": False,
                 "now": now,
@@ -424,7 +424,7 @@ def train_diffusion_model(
             },
         },
         "image_logger": {
-            "target": "imaginairy.train.ImageLogger",
+            "target": "classy_imaginary.train.ImageLogger",
             "params": {
                 "batch_frequency": 10,
                 "max_images": 1,
@@ -446,13 +446,13 @@ def train_diffusion_model(
             },
         },
         "learning_rate_logger": {
-            "target": "imaginairy.train.LearningRateMonitor",
+            "target": "classy_imaginary.train.LearningRateMonitor",
             "params": {
                 "logging_interval": "step",
                 # "log_momentum": True
             },
         },
-        "cuda_callback": {"target": "imaginairy.train.CUDACallback"},
+        "cuda_callback": {"target": "classy_imaginary.train.CUDACallback"},
     }
 
     default_modelckpt_cfg = {
@@ -492,7 +492,7 @@ def train_diffusion_model(
         "num_workers": num_workers,
         "num_val_workers": num_val_workers,
         "train": {
-            "target": "imaginairy.training_tools.single_concept.SingleConceptDataset",
+            "target": "classy_imaginary.training_tools.single_concept.SingleConceptDataset",
             "params": dataset_config,
         },
     }
