@@ -5,7 +5,7 @@
  * For full license text, see LICENSE.txt file in the repo root or https://opensource.org/licenses/BSD-3-Clause
  * By Junnan Li
  * Based on huggingface code base
- * https://github.com/huggingface/transformers/blob/v4.15.0/src/transformers/models/bert
+ * https://github.com/huggingface/transformers/blob/v4.15.0/src/transformers/models/bert.
 """
 
 import math
@@ -611,7 +611,7 @@ class BertPreTrainedModel(PreTrainedModel):
     _keys_to_ignore_on_load_missing = [r"position_ids"]
 
     def _init_weights(self, module):
-        """Initialize the weights"""
+        """Initialize the weights."""
         if isinstance(module, (nn.Linear, nn.Embedding)):
             # Slightly different from the TF version which uses truncated_normal for initialization
             # cf https://github.com/pytorch/pytorch/pull/5617
@@ -654,7 +654,7 @@ class BertModel(BertPreTrainedModel):
     def _prune_heads(self, heads_to_prune):
         """
         Prunes heads of the model. heads_to_prune: dict of {layer_num: list of heads to prune in this layer} See base
-        class PreTrainedModel
+        class PreTrainedModel.
         """
         for layer, heads in heads_to_prune.items():
             self.encoder.layer[layer].attention.prune_heads(heads)
@@ -977,7 +977,7 @@ class BertLMHeadModel(BertPreTrainedModel):
             >>> model = BertLMHeadModel.from_pretrained('bert-base-cased', config=config)
             >>> inputs = tokenizer("Hello, my dog is cute", return_tensors="pt")
             >>> outputs = model(**inputs)
-            >>> prediction_logits = outputs.logits
+            >>> prediction_logits = outputs.logits.
         """
         return_dict = (
             return_dict if return_dict is not None else self.config.use_return_dict
